@@ -1004,6 +1004,8 @@ MProtein::MProtein(istream& is, bool cAlphaOnly)
 	{
 		string line;
 		getline(is, line);
+		if (line.empty() and is.eof())
+			break;
 
 		if (VERBOSE > 3)
 			cerr << line << endl;
@@ -1040,6 +1042,13 @@ MProtein::MProtein(istream& is, bool cAlphaOnly)
 			continue;
 		}
 		
+		if (ba::starts_with(line, "DBREF"))
+		{
+			ba::trim(line);
+			mDbRef.push_back(line);
+			continue;
+		}
+		
 		// brain dead support for only the first model in the file (NMR)
 		if (ba::starts_with(line, "MODEL"))
 		{
@@ -1448,7 +1457,7 @@ void MProtein::Rotate(const MQuaternion& inRotation)
 		chain->Rotate(inRotation);
 }
 
-void MProtein::CalculateSecondaryStructure()
+void MProtein::CalculateSecondaryStructure(bool inPreferPiHelices)
 {
 	vector<MResidue*> residues;
 	residues.reserve(mResidueCount);
@@ -1462,7 +1471,7 @@ void MProtein::CalculateSecondaryStructure()
 
 	CalculateHBondEnergies(residues);
 	CalculateBetaSheets(residues);
-	CalculateAlphaHelices(residues);
+	CalculateAlphaHelices(residues, inPreferPiHelices);
 
 	t.join();
 }
@@ -1492,7 +1501,7 @@ void MProtein::CalculateHBondEnergies(const std::vector<MResidue*>& inResidues)
 }
 
 // TODO: improve alpha helix calculation by better recognizing pi-helices 
-void MProtein::CalculateAlphaHelices(const std::vector<MResidue*>& inResidues)
+void MProtein::CalculateAlphaHelices(const std::vector<MResidue*>& inResidues, bool inPreferPiHelices)
 {
 	if (VERBOSE)
 		cerr << "Calculate alhpa helices" << endl;
@@ -1562,7 +1571,8 @@ void MProtein::CalculateAlphaHelices(const std::vector<MResidue*>& inResidues)
 		{
 			bool empty = true;
 			for (uint32 j = i; empty and j <= i + 4; ++j)
-				empty = inResidues[j]->GetSecondaryStructure() == loop or inResidues[j]->GetSecondaryStructure() == helix_5;
+				empty = inResidues[j]->GetSecondaryStructure() == loop or inResidues[j]->GetSecondaryStructure() == helix_5 or
+							(inPreferPiHelices and inResidues[j]->GetSecondaryStructure() == alphahelix);
 			if (empty)
 			{
 				for (uint32 j = i; j <= i + 4; ++j)
